document.addEventListener('DOMContentLoaded', () => {
  const messageContainer = document.getElementById('message-container');
  const messageForm = document.getElementById('chat-form');
  const messageInput = document.getElementById('message-input');
  const onlineUsers = document.getElementById('online-users');
  const chatRooms = document.getElementById('chat-rooms');

  let ws;
  
  function connectWebSocket() {
    ws = new WebSocket(`wss://${window.location.host}/ws`);
    
    ws.onopen = () => {
      console.log('Connected to WebSocket server');
      addSystemMessage('Connected to chat server');
    };
    
    ws.onmessage = (event) => {
      const message = JSON.parse(event.data);
      displayMessage(message);
    };
    
    ws.onclose = () => {
      console.log('Disconnected from WebSocket server');
      addSystemMessage('Disconnected from chat server. Reconnecting...');
      setTimeout(connectWebSocket, 3000);
    };
    
    ws.onerror = (error) => {
      console.error('WebSocket error:', error);
      addSystemMessage('Error connecting to chat server');
    };
  }

  function displayMessage(message) {
    const messageElement = document.createElement('div');
    messageElement.classList.add('message');
    
    const timestamp = new Date().toLocaleTimeString();
    messageElement.innerHTML = `
      <span class="timestamp">${timestamp}</span>
      <span class="username">${message.username}</span>
      <span class="content">${escapeHtml(message.content)}</span>
    `;
    
    messageContainer.appendChild(messageElement);
    messageContainer.scrollTop = messageContainer.scrollHeight;
  }

  function addSystemMessage(text) {
    const messageElement = document.createElement('div');
    messageElement.classList.add('system-message');
    messageElement.textContent = text;
    messageContainer.appendChild(messageElement);
    messageContainer.scrollTop = messageContainer.scrollHeight;
  }

  function escapeHtml(unsafe) {
    return unsafe
      .replace(/&/g, "&amp;")
      .replace(/</g, "&lt;")
      .replace(/>/g, "&gt;")
      .replace(/"/g, "&quot;")
      .replace(/'/g, "&#039;");
  }

  messageForm.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const message = messageInput.value.trim();
    if (message && ws.readyState === WebSocket.OPEN) {
      ws.send(JSON.stringify({
        type: 'message',
        content: message
      }));
      messageInput.value = '';
    }
  });

  // Initialize demo chat rooms
  const demoRooms = ['General', 'Tech', 'Random'];
  demoRooms.forEach(room => {
    const li = document.createElement('li');
    li.textContent = room;
    chatRooms.appendChild(li);
  });

  // Initialize demo online users
  const demoUsers = ['Alice', 'Bob', 'Charlie'];
  demoUsers.forEach(user => {
    const li = document.createElement('li');
    li.textContent = user;
    onlineUsers.appendChild(li);
  });

  // Start WebSocket connection
  connectWebSocket();
});
